@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
-import json
 import subprocess
 import sys
+import yaml
 
 from halo import Halo
 
@@ -120,9 +120,7 @@ def twigify(projects_list):
             "default_branch": False,
         }
 
-    return json.dumps(
-        json.dumps(projects_dict)
-    )  # necessario per fare l'escape corretto
+    return f'"{yaml.dump(projects_dict, explicit_start=True, default_flow_style=False)}"'  # necessario per fare l'escape corretto
 
     # development only
     # return json.dumps(projects_dict) chiamando twig da file non bisogna dumpare due volte
