@@ -1,6 +1,6 @@
 # -*- encoding: utf-8 -*-
-import json
 import subprocess
+import yaml
 
 from suite_py.lib.logger import Logger
 from suite_py.lib.config import Config
@@ -13,7 +13,9 @@ logger = Logger()
 github = GithubHandler()
 
 # development only
-# twig_command = '{}/twig-binaries/bin/twig-feature'.format(config.load()['user']['projects_home'])
+# twig_command = "{}/twig-binaries/bin/twig-feature".format(
+#     config.load()["user"]["projects_home"]
+# )
 
 qainit_dir = f"{config.load()['user']['projects_home']}/qainit"
 
@@ -21,8 +23,8 @@ qainit_dir = f"{config.load()['user']['projects_home']}/qainit"
 def get_qa_projects():
     git.check_repo_cloned("qainit")
     git.sync("qainit")
-    with open(f"{qainit_dir}/branch_names", "r") as file:
-        branches_obj = json.loads(file.read())
+    with open(f"{qainit_dir}/projects.yml", "r") as file:
+        branches_obj = yaml.load(file.read())
 
     return list(branches_obj.keys())
 
@@ -30,7 +32,7 @@ def get_qa_projects():
 def qainit_deploy(args):
     return subprocess.run(
         # development only
-        # [twig_command, 'suite', 'deploy', args], cwd=qainit_dir, check=True)
+        # [twig_command, "suite", "deploy", args],
         ["twig", "feature", "suite", "deploy", args],
         cwd=qainit_dir,
         check=True,
